From caa1d8a49a7b2b5d8d3c4371a666183fdf9bf24a Mon Sep 17 00:00:00 2001
From: Portisch <hugo.portisch@yahoo.de>
Date: Sun, 27 Aug 2023 13:45:10 +0200
Subject: [PATCH] bl30_manager: send scpi cmds only by sysfs call

---
 drivers/bootloader/bl301_manager.c | 46 +++++++++++++++++++++++-------
 1 file changed, 35 insertions(+), 11 deletions(-)

diff --git a/drivers/bootloader/bl301_manager.c b/drivers/bootloader/bl301_manager.c
index d4bd9c221ba8..cea83d993ba1 100644
--- a/drivers/bootloader/bl301_manager.c
+++ b/drivers/bootloader/bl301_manager.c
@@ -103,18 +103,12 @@ static struct platform_driver bl301_manager_driver = {
 	},
 };
 
-static int __init bl301_manager_init(void)
-{
-	int ret;
-
-	ret = platform_driver_register(&bl301_manager_driver);
-	if (ret < 0) {
-			pr_info("%s: unable to register platform driver\n", DRIVER_NAME);
-			return ret;
-	}
-
-	pr_info("%s: driver init\n", DRIVER_NAME);
+static ssize_t setup_bl301_store(struct class *cla,
+			     struct class_attribute *attr,
+			     const char *buf, size_t count)
 
+{
+	pr_info("%s: Do setup BL301 blob\n", DRIVER_NAME);
 	pr_info("%s: IR remote wake-up code: 0x%x\n", DRIVER_NAME, remotewakeup);
 	pr_info("%s: IR remote wake-up code mask: 0x%x\n", DRIVER_NAME, remotewakeupmask);
 	pr_info("%s: IR remote wake-up code protocol: 0x%x\n", DRIVER_NAME, decode_type);
@@ -130,12 +124,42 @@ static int __init bl301_manager_init(void)
 	scpi_send_usr_data(SCPI_CL_5V_SYSTEM_POWER, &enable_system_power,
 		sizeof(enable_system_power));
 
+	return count;
+}
+
+static struct class_attribute bl301_manager_class_attrs[] = {
+	__ATTR_WO(setup_bl301),
+	__ATTR_NULL
+};
+
+static struct class bl301_manager_class = {
+	.name = DRIVER_NAME,
+	.class_attrs = bl301_manager_class_attrs,
+};
+
+static int __init bl301_manager_init(void)
+{
+	int ret;
+
+	ret = platform_driver_register(&bl301_manager_driver);
+	if (ret < 0) {
+			pr_info("%s: unable to register platform driver\n", DRIVER_NAME);
+			return ret;
+	}
+
+	ret = class_register(&bl301_manager_class);
+	if (ret)
+		pr_err("%s: create class fail.\n", DRIVER_NAME);
+
+	pr_info("%s: driver init\n", DRIVER_NAME);
+
 	return 0;
 }
 
 static void __exit bl301_manager_exit(void)
 {
 	platform_driver_unregister(&bl301_manager_driver);
+	class_unregister(&bl301_manager_class);
 	pr_info("%s: driver exited\n", DRIVER_NAME);
 }
 
-- 
2.41.0

